@@ -10,8 +10,11 @@ __all__ = ['NIE', 'NIEMajorAxis']
 
 class NIE(LensProfileBase):
     """
-    Non-singular isothermal ellipsoid
-    kappa = theta_E/2 [s2IE + r2(1 − e * cos(2*phi)]−1/2
+    Non-singular isothermal ellipsoid (NIE)
+
+    .. math::
+     \\kappa = \\theta_E/2 \\left[s_{scale} + qx^2 + y^2/q]−1/2
+
     """
     param_names = ['theta_E', 'e1', 'e2', 's_scale', 'center_x', 'center_y']
     lower_limit_default = {'theta_E': 0, 'e1': -0.5, 'e2': -0.5, 's_scale': 0, 'center_x': -100, 'center_y': -100}
@@ -21,61 +24,6 @@ class NIE(LensProfileBase):
         self.nie_major_axis = NIEMajorAxis()
         super(NIE, self).__init__()
 
-    def param_conv(self, theta_E, e1, e2, s_scale):
-        if self._static is True:
-            return self._b_static, self._s_static, self._q_static, self._phi_G_static
-        return self._param_conv(theta_E, e1, e2, s_scale)
-
-    def _param_conv(self, theta_E, e1, e2, s_scale):
-        """
-        convert parameters from 2*kappa = bIE [s2IE + r2(1 − e *cos(2*phi)]−1/2 to
-        2*kappa=  b *(q2(s2 + x2) + y2􏰉)−1/2
-        see expressions after Equation 8 in Keeton and Kochanek 1998, https://arxiv.org/pdf/astro-ph/9705194.pdf
-
-        :param theta_E: Einstein radius
-        :param e1: eccentricity component
-        :param e2: eccentricity component
-        :param s_scale: smoothing scale
-        :return: critical radius b, smoothing scale s, axis ratio q, orientation angle phi_G
-        """
-
-        phi_G, q = param_util.ellipticity2phi_q(e1, e2)
-        theta_E_conv = self._theta_E_q_convert(theta_E, q)
-        b = theta_E_conv * np.sqrt((1 + q**2)/2)
-        s = s_scale * np.sqrt((1 + q**2) / (2*q**2))
-        return b, s, q, phi_G
-
-    def set_static(self, theta_E, e1, e2, s_scale, center_x=0, center_y=0):
-        """
-
-        :param x: x-coordinate in image plane
-        :param y: y-coordinate in image plane
-        :param theta_E: Einstein radius
-        :param e1: eccentricity component
-        :param e2: eccentricity component
-        :param s_scale: smoothing scale
-        :param center_x: profile center
-        :param center_y: profile center
-        :return: self variables set
-        """
-        self._static = True
-        self._b_static, self._s_static, self._q_static, self._phi_G_static = self._param_conv(theta_E, e1, e2, s_scale)
-
-    def set_dynamic(self):
-        """
-
-        :return:
-        """
-        self._static = False
-        if hasattr(self, '_b_static'):
-            del self._b_static
-        if hasattr(self, '_s_static'):
-            del self._s_static
-        if hasattr(self, '_phi_G_static'):
-            del self._phi_G_static
-        if hasattr(self, '_q_static'):
-            del self._q_static
-
     def function(self, x, y, theta_E, e1, e2, s_scale, center_x=0, center_y=0):
         """
 
@@ -157,18 +105,112 @@ class NIE(LensProfileBase):
         f_xy = gamma2
         return f_xx, f_xy, f_xy, f_yy
 
-    def _theta_E_q_convert(self, theta_E, q):
+    def density_lens(self, r, theta_E, e1, e2, s_scale, center_x=0, center_y=0):
         """
-        converts a spherical averaged Einstein radius to an elliptical (major axis) Einstein radius.
-        This then follows the convention of the SPEMD profile in lenstronomy.
-        (theta_E / theta_E_gravlens) = sqrt[ (1+q^2) / (2 q) ]
+        3d mass density at 3d radius r. This function assumes spherical symmetry/ignoring the eccentricity.
 
-        :param theta_E: Einstein radius in lenstronomy conventions
-        :param q: axis ratio minor/major
-        :return: theta_E in convention of kappa=  b *(q2(s2 + x2) + y2􏰉)−1/2
+        :param r: 3d radius
+        :param theta_E: Einstein radius
+        :param e1: eccentricity component
+        :param e2: eccentricity component
+        :param s_scale: smoothing scale
+        :param center_x: profile center
+        :param center_y: profile center
+        :return: 3d mass density at 3d radius r
         """
-        theta_E_new = theta_E / (np.sqrt((1.+q**2) / (2. * q))) #/ (1+(1-q)/2.)
-        return theta_E_new
+        # kappa=1/2 at Einstein radius
+        rho0 = 1 / 2 * theta_E / np.pi
+        return rho0 / (r**2 + s_scale**2)
+
+    def mass_3d_lens(self, r, theta_E, e1, e2, s_scale, center_x=0, center_y=0):
+        """
+        mass enclosed a 3d radius r. This function assumes spherical symmetry/ignoring the eccentricity.
+
+        :param r: 3d radius
+        :param theta_E: Einstein radius
+        :param e1: eccentricity component
+        :param e2: eccentricity component
+        :param s_scale: smoothing scale
+        :param center_x: profile center
+        :param center_y: profile center
+        :return: 3d mass density at 3d radius r
+        """
+        rho0 = 1 / 2 * theta_E / np.pi
+        return rho0 * 4 * np.pi * (r - s_scale * np.arctan(r/s_scale))
+
+    def param_conv(self, theta_E, e1, e2, s_scale):
+        if self._static is True:
+            return self._b_static, self._s_static, self._q_static, self._phi_G_static
+        return self._param_conv(theta_E, e1, e2, s_scale)
+
+    def _param_conv(self, theta_E, e1, e2, s_scale):
+        """
+        convert parameters from 2*kappa = bIE [s2IE + r2(1 − e *cos(2*phi)]−1/2 to
+        2*kappa=  b *(q2(s2 + x2) + y2􏰉)−1/2
+        see expressions after Equation 8 in Keeton and Kochanek 1998, https://arxiv.org/pdf/astro-ph/9705194.pdf
+
+        :param theta_E: Einstein radius
+        :param e1: eccentricity component
+        :param e2: eccentricity component
+        :param s_scale: smoothing scale
+        :return: critical radius b, smoothing scale s, axis ratio q, orientation angle phi_G
+        """
+
+        phi_G, q = param_util.ellipticity2phi_q(e1, e2)
+        theta_E_conv = self._theta_E_prod_average2major_axis(theta_E, q)
+        b = theta_E_conv * np.sqrt((1 + q**2)/2)
+        s = s_scale / np.sqrt(q)
+        #s = s_scale * np.sqrt((1 + q**2) / (2*q**2))
+        return b, s, q, phi_G
+
+    def set_static(self, theta_E, e1, e2, s_scale, center_x=0, center_y=0):
+        """
+
+        :param x: x-coordinate in image plane
+        :param y: y-coordinate in image plane
+        :param theta_E: Einstein radius
+        :param e1: eccentricity component
+        :param e2: eccentricity component
+        :param s_scale: smoothing scale
+        :param center_x: profile center
+        :param center_y: profile center
+        :return: self variables set
+        """
+        self._static = True
+        self._b_static, self._s_static, self._q_static, self._phi_G_static = self._param_conv(theta_E, e1, e2, s_scale)
+
+    def set_dynamic(self):
+        """
+
+        :return:
+        """
+        self._static = False
+        if hasattr(self, '_b_static'):
+            del self._b_static
+        if hasattr(self, '_s_static'):
+            del self._s_static
+        if hasattr(self, '_phi_G_static'):
+            del self._phi_G_static
+        if hasattr(self, '_q_static'):
+            del self._q_static
+
+    @staticmethod
+    def _theta_E_prod_average2major_axis(theta_E, q):
+        """
+        Converts a product averaged Einstein radius (of semi-minor and semi-major axis) to a major axis Einstein radius
+        for an Isothermal ellipse.
+        The standard lenstronomy conventions are product averaged Einstein radii while other codes
+        (such as e.g. gravlens) use the semi-major axis convention.
+
+        .. math::
+          \\frac{\\theta_{E, prod ave}}{\\theta_{E, major}} = \\sqrt{(1+q^2) / (2 q) }
+
+        :param theta_E: Einstein radius in lenstronomy conventions (product average of major and minor axes)
+        :param q: axis ratio minor/major
+        :return: theta_E in convention of kappa= b *(q^2(s^2 + x^2) + y^2􏰉)^{−1/2} (major axis)
+        """
+        theta_E_major_axis = theta_E / (np.sqrt((1.+q**2) / (2. * q)))
+        return theta_E_major_axis
 
 
 class NIEMajorAxis(LensProfileBase):
@@ -177,7 +219,7 @@ class NIEMajorAxis(LensProfileBase):
     See Keeton and Kochanek 1998, https://arxiv.org/pdf/astro-ph/9705194.pdf
 
     .. math::
-        \kappa =  b *(q2(s2 + x2) + y2􏰉)^{−1/2}`
+        \\kappa =  b * (q2(s2 + x2) + y2􏰉)^{−1/2}`
 
     """
 
