@@ -14,6 +14,11 @@ class TNFW(LensProfileBase):
     """
     this class contains functions concerning the truncated NFW profile with a truncation function (r_trunc^2)*(r^2+r_trunc^2)
 
+    density equation is:
+
+    .. math::
+        \\rho(r) = \\frac{r_\\text{trunc}^2}{r^2+r_\\text{trunc}^2}\\frac{\\rho_0(\\alpha_{R_s})}{r/R_s(1+r/R_s)^2}
+
     relation are: R_200 = c * Rs
 
     """
