@@ -24,24 +24,30 @@ class ProfileListBase(object):
     class that manages the list of lens model class instances. This class is applicable for single plane and multi
     plane lensing
     """
-    def __init__(self, lens_model_list, numerical_alpha_class=None, lens_redshift_list=None, z_source_convention=None):
+    def __init__(self, lens_model_list, numerical_alpha_class=None, lens_redshift_list=None, z_source_convention=None,
+                 kwargs_interp=None):
         """
 
         :param lens_model_list: list of strings with lens model names
         :param numerical_alpha_class: an instance of a custom class for use in NumericalAlpha() lens model
         deflection angles as a lens model. See the documentation in Profiles.numerical_deflections
+        :param kwargs_interp: interpolation keyword arguments specifying the numerics.
+         See description in the Interpolate() class. Only applicable for 'INTERPOL' and 'INTERPOL_SCALED' models.
         """
 
         self.func_list = self._load_model_instances(lens_model_list, custom_class=numerical_alpha_class,
                                                     lens_redshift_list=lens_redshift_list,
-                                                    z_source_convention=z_source_convention)
+                                                    z_source_convention=z_source_convention,
+                                                    kwargs_interp=kwargs_interp)
         self._num_func = len(self.func_list)
         self._model_list = lens_model_list
 
     def _load_model_instances(self, lens_model_list, custom_class=None, lens_redshift_list=None,
-                              z_source_convention=None):
+                              z_source_convention=None, kwargs_interp=None):
         if lens_redshift_list is None:
             lens_redshift_list = [None] * len(lens_model_list)
+        if kwargs_interp is None:
+            kwargs_interp = {}
         func_list = []
         imported_classes = {}
         for i, lens_type in enumerate(lens_model_list):
@@ -49,10 +55,10 @@ class ProfileListBase(object):
             if lens_type in ['NFW_MC', 'CHAMELEON', 'DOUBLE_CHAMELEON', 'TRIPLE_CHAMELEON', 'NFW_ELLIPSE_GAUSS_DEC',
                              'CTNFW_GAUSS_DEC', 'INTERPOL', 'INTERPOL_SCALED', 'NIE', 'NIE_SIMPLE']:
                 lensmodel_class = self._import_class(lens_type, custom_class, z_lens=lens_redshift_list[i],
-                                                     z_source=z_source_convention)
+                                                     z_source=z_source_convention, kwargs_interp=kwargs_interp)
             else:
                 if lens_type not in imported_classes.keys():
-                    lensmodel_class = self._import_class(lens_type, custom_class)
+                    lensmodel_class = self._import_class(lens_type, custom_class, kwargs_interp=kwargs_interp)
                     imported_classes.update({lens_type: lensmodel_class})
                 else:
                     lensmodel_class = imported_classes[lens_type]
@@ -60,13 +66,15 @@ class ProfileListBase(object):
         return func_list
 
     @staticmethod
-    def _import_class(lens_type, custom_class, z_lens=None, z_source=None):
+    def _import_class(lens_type, custom_class, kwargs_interp, z_lens=None, z_source=None):
         """
 
         :param lens_type: string, lens model type
         :param custom_class: custom class
         :param z_lens: lens redshift  # currently only used in NFW_MC model as this is redshift dependent
         :param z_source: source redshift  # currently only used in NFW_MC model as this is redshift dependent
+        :param kwargs_interp: interpolation keyword arguments specifying the numerics.
+         See description in the Interpolate() class. Only applicable for 'INTERPOL' and 'INTERPOL_SCALED' models.
         :return: class instance of the lens model type
         """
 
@@ -219,10 +227,10 @@ class ProfileListBase(object):
             return MultiGaussianKappaEllipse()
         elif lens_type == 'INTERPOL':
             from lenstronomy.LensModel.Profiles.interpol import Interpol
-            return Interpol()
+            return Interpol(**kwargs_interp)
         elif lens_type == 'INTERPOL_SCALED':
             from lenstronomy.LensModel.Profiles.interpol import InterpolScaled
-            return InterpolScaled()
+            return InterpolScaled(**kwargs_interp)
         elif lens_type == 'SHAPELETS_POLAR':
             from lenstronomy.LensModel.Profiles.shapelet_pot_polar import PolarShapelets
             return PolarShapelets()
