@@ -58,15 +58,17 @@ class TestGalkin(object):
         kwargs_model = {'mass_profile_list': mass_profile_list,
                         'light_profile_list': light_profile_list,
                         'anisotropy_model': anisotropy_type}
+        kwargs_numerics = {'interpol_grid_num': 100, 'log_integration': True,
+                           'max_integrate': 100, 'min_integrate': 0.01}
         galkin = Galkin(kwargs_model=kwargs_model, kwargs_psf=kwargs_psf, kwargs_cosmo=kwargs_cosmo,
-                        kwargs_aperture=kwargs_aperture, kwargs_numerics={})
+                        kwargs_aperture=kwargs_aperture, kwargs_numerics=kwargs_numerics)
         sigma_v = galkin.dispersion(kwargs_profile, kwargs_light, kwargs_anisotropy)
 
         kwargs_model_mge = {'mass_profile_list': mass_profile_list,
                         'light_profile_list': light_profile_list_mge,
                         'anisotropy_model': anisotropy_type}
         galkin = Galkin(kwargs_model=kwargs_model_mge, kwargs_psf=kwargs_psf, kwargs_cosmo=kwargs_cosmo,
-                        kwargs_aperture=kwargs_aperture, kwargs_numerics={})
+                        kwargs_aperture=kwargs_aperture, kwargs_numerics=kwargs_numerics)
         sigma_v2 = galkin.dispersion(kwargs_profile, kwargs_light_mge, kwargs_anisotropy)
 
         print(sigma_v, sigma_v2, 'sigma_v Galkin, sigma_v MGEn')
@@ -106,7 +108,7 @@ class TestGalkin(object):
 
         # mge of lens profile
         lensModel = LensModel(mass_profile_list)
-        r_array = np.logspace(-2, 1, 100)*theta_E
+        r_array = np.logspace(-2, 2, 100)*theta_E
         kappa_r = lensModel.kappa(r_array, 0, kwargs_profile)
         amps, sigmas, norm = mge.mge_1d(r_array, kappa_r, N=20)
         mass_profile_list_mge = ['MULTI_GAUSSIAN_KAPPA']
@@ -115,16 +117,18 @@ class TestGalkin(object):
         kwargs_model = {'mass_profile_list': mass_profile_list,
                         'light_profile_list': light_profile_list,
                         'anisotropy_model': anisotropy_type}
+        kwargs_numerics = {'interpol_grid_num': 100, 'log_integration': True,
+                           'max_integrate': 100, 'min_integrate': 0.01}
 
         galkin = Galkin(kwargs_model=kwargs_model, kwargs_psf=kwargs_psf, kwargs_cosmo=kwargs_cosmo,
-                        kwargs_aperture=kwargs_aperture, kwargs_numerics={})
+                        kwargs_aperture=kwargs_aperture, kwargs_numerics=kwargs_numerics)
         sigma_v = galkin.dispersion(kwargs_profile, kwargs_light, kwargs_anisotropy)
 
         kwargs_model = {'mass_profile_list': mass_profile_list_mge,
                         'light_profile_list': light_profile_list,
                         'anisotropy_model': anisotropy_type}
         galkin = Galkin(kwargs_model=kwargs_model, kwargs_psf=kwargs_psf, kwargs_cosmo=kwargs_cosmo,
-                        kwargs_aperture=kwargs_aperture, kwargs_numerics={})
+                        kwargs_aperture=kwargs_aperture, kwargs_numerics=kwargs_numerics)
         sigma_v2 = galkin.dispersion(kwargs_profile_mge, kwargs_light, kwargs_anisotropy)
 
         print(sigma_v, sigma_v2, 'sigma_v Galkin, sigma_v MGEn')
@@ -177,9 +181,10 @@ class TestGalkin(object):
         kwargs_model = {'mass_profile_list': mass_profile_list,
                         'light_profile_list': light_profile_list,
                         'anisotropy_model': anisotropy_model}
-
+        kwargs_numerics = {'interpol_grid_num': 100, 'log_integration': True,
+                           'max_integrate': 100, 'min_integrate': 0.01}
         galkin = Galkin(kwargs_model=kwargs_model, kwargs_psf=kwargs_psf, kwargs_cosmo=kwargs_cosmo,
-                        kwargs_aperture=kwargs_aperture, kwargs_numerics={})
+                        kwargs_aperture=kwargs_aperture, kwargs_numerics=kwargs_numerics)
         sigma_v = galkin.dispersion(kwargs_profile, kwargs_light, kwargs_anisotropy)
 
         kwargs_model_mge = {'mass_profile_list': mass_profile_list_mge,
@@ -187,7 +192,7 @@ class TestGalkin(object):
                         'anisotropy_model': anisotropy_model}
 
         galkin = Galkin(kwargs_model=kwargs_model_mge, kwargs_psf=kwargs_psf, kwargs_cosmo=kwargs_cosmo,
-                        kwargs_aperture=kwargs_aperture, kwargs_numerics={})
+                        kwargs_aperture=kwargs_aperture, kwargs_numerics=kwargs_numerics)
         sigma_v2 = galkin.dispersion(kwargs_profile_mge, kwargs_light_mge, kwargs_anisotropy)
 
         print(sigma_v, sigma_v2, 'sigma_v Galkin, sigma_v MGEn')
